@@ -5,7 +5,15 @@ from .common import InfoExtractor
 
 class InaIE(InfoExtractor):
     """Information Extractor for Ina.fr"""
-    _VALID_URL = r'(?:http://)?(?:www\.)?ina\.fr/video/(?P<id>I[0-9]+)/.*'
+    _VALID_URL = r'(?:http://)?(?:www\.)?ina\.fr/video/(?P<id>[A-F0-9]+)/.*'
+    _TEST = {
+        u'url': u'www.ina.fr/video/I12055569/francois-hollande-je-crois-que-c-est-clair-video.html',
+        u'file': u'I12055569.mp4',
+        u'md5': u'a667021bf2b41f8dc6049479d9bb38a3',
+        u'info_dict': {
+            u"title": u"Fran\u00e7ois Hollande \"Je crois que c'est clair\""
+        }
+    }
 
     def _real_extract(self,url):
         mobj = re.match(self._VALID_URL, url)
